@@ -63,7 +63,7 @@ char *GPJ_grass_to_wkt( struct Key_Value *,
 
 #define GRASS_MAX_COLORS 100000  // what is the right value
 
-CPL_CVSID("$Id: grass57dataset.cpp 37964 2017-04-11 18:04:50Z rouault $");
+CPL_CVSID("$Id: grass57dataset.cpp c4d5cfef28c1c6fbb03a9ab1d42835e6cfa920cc 2017-12-20 12:29:27Z Kurt Schwehr $")
 
 #if GRASS_VERSION_MAJOR  >= 7
 #define G_get_cellhd             Rast_get_cellhd
@@ -132,11 +132,11 @@ class GRASSDataset : public GDALDataset
     double      adfGeoTransform[6];
 
   public:
-                 GRASSDataset();
-                 ~GRASSDataset();
+    GRASSDataset();
+    ~GRASSDataset() override;
 
-    virtual const char *GetProjectionRef(void) override;
-    virtual CPLErr GetGeoTransform( double * ) override;
+    const char *GetProjectionRef(void) override;
+    CPLErr GetGeoTransform( double * ) override;
 
     static GDALDataset *Open( GDALOpenInfo * );
 
@@ -174,21 +174,20 @@ class GRASSRasterBand : public GDALRasterBand
     bool        valid;
 
   public:
+    GRASSRasterBand( GRASSDataset *, int, const char *, const char * );
+    ~GRASSRasterBand() override;
 
-                   GRASSRasterBand( GRASSDataset *, int,
-                                    const char *, const char * );
-    virtual        ~GRASSRasterBand();
-
-    virtual CPLErr IReadBlock( int, int, void * ) override;
-    virtual CPLErr IRasterIO ( GDALRWFlag, int, int, int, int, void *, int, int, GDALDataType,
-                               GSpacing nPixelSpace,
-                               GSpacing nLineSpace,
-                               GDALRasterIOExtraArg* psExtraArg) override;
-    virtual GDALColorInterp GetColorInterpretation() override;
-    virtual GDALColorTable *GetColorTable() override;
-    virtual double GetMinimum( int *pbSuccess = NULL ) override;
-    virtual double GetMaximum( int *pbSuccess = NULL ) override;
-    virtual double GetNoDataValue( int *pbSuccess = NULL ) override;
+    CPLErr IReadBlock( int, int, void * ) override;
+    CPLErr IRasterIO ( GDALRWFlag, int, int, int, int,
+                       void *, int, int, GDALDataType,
+                       GSpacing nPixelSpace,
+                       GSpacing nLineSpace,
+                       GDALRasterIOExtraArg* psExtraArg) override;
+    GDALColorInterp GetColorInterpretation() override;
+    GDALColorTable *GetColorTable() override;
+    double GetMinimum( int *pbSuccess = NULL ) override;
+    double GetMaximum( int *pbSuccess = NULL ) override;
+    double GetNoDataValue( int *pbSuccess = NULL ) override;
 
   private:
     CPLErr ResetReading( struct Cell_head * );
